<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.Services.TargetedContent

Windows Runtime (WinRT) APIs for for the `Windows.Services.TargetedContent` namespace.

This package provides the `winrt.windows.services.targetedcontent` module.
